@@ -1,6 +1,6 @@
 /*
   tryopen.c -- tool for tests that try opening zip archives
-  Copyright (C) 1999-2018 Dieter Baron and Thomas Klausner
+  Copyright (C) 1999-2019 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
   The authors can be contacted at <libzip@nih.at>
@@ -46,12 +46,11 @@
 
 #include "compat.h"
 #include "zip.h"
-
-const char *usage = "usage: %s [-cent] file\n\n"
-		    "\t-c\tcheck consistency\n"
-		    "\t-e\texclusively open archive\n"
-		    "\t-n\tcreate new file\n"
-		    "\t-t\ttruncate file to size 0\n";
+#define TRYOPEN_USAGE "usage: %s [-cent] file\n\n" \
+		      "\t-c\tcheck consistency\n" \
+		      "\t-e\texclusively open archive\n" \
+		      "\t-n\tcreate new file\n" \
+		      "\t-t\ttruncate file to size 0\n"
 
 
 int
@@ -80,7 +79,7 @@ main(int argc, char *argv[]) {
 	    break;
 
 	default:
-	    fprintf(stderr, usage, argv[0]);
+	    fprintf(stderr, TRYOPEN_USAGE, argv[0]);
 	    return 1;
 	}
     }
